package com.landray.kmss.sys.attachment.thirdSfs.util;

import com.landray.kmss.sys.attachment.thirdSfs.service.SysAttExtendThirdProxyService;
import com.landray.kmss.framework.plugin.core.config.IExtension;
import com.landray.kmss.framework.plugin.core.config.IExtensionPoint;
import com.landray.kmss.util.SpringBeanUtil;
import com.landray.kmss.framework.service.plugin.Plugin;
import com.landray.kmss.util.StringUtil;
import com.landray.kmss.sys.attachment.thirdSfs.service.extend.SysAttExtendFoxitProxyService;
import com.landray.kmss.sys.attachment.thirdSfs.service.extend.SysAttExtendSuwellProxyService;
import com.landray.kmss.sys.attachment.thirdSfs.service.extend.SysAttExtendYozoProxyService;
import java.util.Iterator;
import com.landray.kmss.sys.attachment.thirdSfs.service.extend.SysAttExtendWpsCenterProxyService;
import com.landray.kmss.sys.attachment.thirdSfs.service.extend.SysAttExtendWpsCenterV6ProxyService;
import com.landray.kmss.sys.attachment.thirdSfs.service.SysAttStandardThirdProxyService;
import com.landray.kmss.sys.attachment.thirdSfs.vo.ThirdSfsResponseResult;
import com.alibaba.fastjson.JSONObject;
import java.util.ArrayList;
import java.util.List;

public class SysAttThirdProxyUtil
{
    private static List<StandardThirdProxyService> standardThirdProxyServices;
    private static List<ExtendThirdProxyService> extendThirdProxyServices;
    
    static {
        SysAttThirdProxyUtil.standardThirdProxyServices = new ArrayList<StandardThirdProxyService>();
        SysAttThirdProxyUtil.extendThirdProxyServices = new ArrayList<ExtendThirdProxyService>();
    }
    
    public static ThirdSfsResponseResult getToken(final String thirdType, final JSONObject params) throws Exception {
        final SysAttStandardThirdProxyService service = getStandardThirdProxyService(thirdType);
        if (service == null) {
            return null;
        }
        return service.getToken(params);
    }
    
    public static ThirdSfsResponseResult getViewUrl(final String thirdType, final JSONObject params) throws Exception {
        final SysAttStandardThirdProxyService service = getStandardThirdProxyService(thirdType);
        if (service == null) {
            return null;
        }
        return service.getViewUrl(params);
    }
    
    public static ThirdSfsResponseResult getEditUrl(final String thirdType, final JSONObject params) throws Exception {
        final SysAttStandardThirdProxyService service = getStandardThirdProxyService(thirdType);
        if (service == null) {
            return null;
        }
        return service.getEditUrl(params);
    }
    
    public static ThirdSfsResponseResult wrapHeader(final String thirdType, final JSONObject params) throws Exception {
        ThirdSfsResponseResult result = null;
        final List<ExtendThirdProxyService> extendThirdProxyServices = getExtendThirdProxyServices();
        for (final ExtendThirdProxyService proxyService : extendThirdProxyServices) {
            if (proxyService.getKey().equals(thirdType)) {
                switch (thirdType.hashCode()) {
                    case -2110133105: {
                        if (!thirdType.equals("wpsCenterV6")) {
                            continue;
                        }
                        final SysAttExtendWpsCenterV6ProxyService serviceV6 = (SysAttExtendWpsCenterV6ProxyService)proxyService.getProxyService();
                        if ("true".equals(params.getString("sync"))) {
                            result = serviceV6.wrapHeaderSync(params);
                            continue;
                        }
                        result = serviceV6.wrapHeaderTask(params);
                        continue;
                    }
                    case -1713925713: {
                        if (!thirdType.equals("wpsCenter")) {
                            continue;
                        }
                        final SysAttExtendWpsCenterProxyService service = (SysAttExtendWpsCenterProxyService)proxyService.getProxyService();
                        result = service.wrapHeader(params);
                        continue;
                    }
                    default: {
                        continue;
                    }
                }
            }
        }
        return result;
    }
    
    public static ThirdSfsResponseResult saveEditOnline(final String thirdType, final JSONObject params) throws Exception {
        ThirdSfsResponseResult result = null;
        final List<ExtendThirdProxyService> extendThirdProxyServices = getExtendThirdProxyServices();
        for (final ExtendThirdProxyService proxyService : extendThirdProxyServices) {
            if (proxyService.getKey().equals(thirdType)) {
                switch (thirdType.hashCode()) {
                    case -2110133105: {
                        if (!thirdType.equals("wpsCenterV6")) {
                            continue;
                        }
                        final SysAttExtendWpsCenterV6ProxyService serviceV6 = (SysAttExtendWpsCenterV6ProxyService)proxyService.getProxyService();
                        result = serviceV6.forceSave(params);
                        continue;
                    }
                    case 3715275: {
                        if (!thirdType.equals("yozo")) {
                            continue;
                        }
                        final SysAttExtendYozoProxyService service = (SysAttExtendYozoProxyService)proxyService.getProxyService();
                        result = service.saveEditOnline(params);
                        continue;
                    }
                    default: {
                        continue;
                    }
                }
            }
        }
        return result;
    }
    
    public static ThirdSfsResponseResult refresh(final String thirdType, final JSONObject params) throws Exception {
        ThirdSfsResponseResult result = null;
        final List<ExtendThirdProxyService> extendThirdProxyServices = getExtendThirdProxyServices();
        for (final ExtendThirdProxyService proxyService : extendThirdProxyServices) {
            if (proxyService.getKey().equals(thirdType)) {
                switch (thirdType.hashCode()) {
                    case -2110133105: {
                        if (!thirdType.equals("wpsCenterV6")) {
                            continue;
                        }
                        final SysAttExtendWpsCenterV6ProxyService serviceV6 = (SysAttExtendWpsCenterV6ProxyService)proxyService.getProxyService();
                        result = serviceV6.refresh(params);
                        continue;
                    }
                    default: {
                        continue;
                    }
                }
            }
        }
        return result;
    }
    
    public static ThirdSfsResponseResult yozoUseApi(final JSONObject params) throws Exception {
        ThirdSfsResponseResult result = null;
        final List<ExtendThirdProxyService> extendThirdProxyServices = getExtendThirdProxyServices();
        for (final ExtendThirdProxyService proxyService : extendThirdProxyServices) {
            if (proxyService.getKey().equals("yozo")) {
                final SysAttExtendYozoProxyService service = (SysAttExtendYozoProxyService)proxyService.getProxyService();
                result = service.yozoUseApi(params);
            }
        }
        return result;
    }
    
    public static ThirdSfsResponseResult modifyAndSave(final String thirdType, final JSONObject params) throws Exception {
        ThirdSfsResponseResult result = null;
        final List<ExtendThirdProxyService> extendThirdProxyServices = getExtendThirdProxyServices();
        for (final ExtendThirdProxyService proxyService : extendThirdProxyServices) {
            if (proxyService.getKey().equals(thirdType)) {
                switch (thirdType.hashCode()) {
                    case 3715275: {
                        if (!thirdType.equals("yozo")) {
                            continue;
                        }
                        final SysAttExtendYozoProxyService service = (SysAttExtendYozoProxyService)proxyService.getProxyService();
                        result = service.modifyAndSave(params);
                        continue;
                    }
                    default: {
                        continue;
                    }
                }
            }
        }
        return result;
    }
    
    public static ThirdSfsResponseResult insertMark(final String thirdType, final JSONObject params) throws Exception {
        ThirdSfsResponseResult result = null;
        final List<ExtendThirdProxyService> extendThirdProxyServices = getExtendThirdProxyServices();
        for (final ExtendThirdProxyService proxyService : extendThirdProxyServices) {
            if (proxyService.getKey().equals(thirdType)) {
                switch (thirdType.hashCode()) {
                    case 3715275: {
                        if (!thirdType.equals("yozo")) {
                            continue;
                        }
                        final SysAttExtendYozoProxyService service = (SysAttExtendYozoProxyService)proxyService.getProxyService();
                        result = service.insertMark(params);
                        continue;
                    }
                    default: {
                        continue;
                    }
                }
            }
        }
        return result;
    }
    
    public static ThirdSfsResponseResult downFile(final String thirdType, final JSONObject params) throws Exception {
        ThirdSfsResponseResult result = null;
        final List<ExtendThirdProxyService> extendThirdProxyServices = getExtendThirdProxyServices();
        for (final ExtendThirdProxyService proxyService : extendThirdProxyServices) {
            if (proxyService.getKey().equals(thirdType)) {
                switch (thirdType.hashCode()) {
                    case -2110133105: {
                        if (!thirdType.equals("wpsCenterV6")) {
                            continue;
                        }
                        final SysAttExtendWpsCenterV6ProxyService serviceV6 = (SysAttExtendWpsCenterV6ProxyService)proxyService.getProxyService();
                        result = serviceV6.download(params);
                        continue;
                    }
                    case 3715275: {
                        if (!thirdType.equals("yozo")) {
                            continue;
                        }
                        final SysAttExtendYozoProxyService service = (SysAttExtendYozoProxyService)proxyService.getProxyService();
                        result = service.downFile(params);
                        continue;
                    }
                    default: {
                        continue;
                    }
                }
            }
        }
        return result;
    }
    
    public static ThirdSfsResponseResult operateClean(final String thirdType, final JSONObject params) throws Exception {
        ThirdSfsResponseResult result = null;
        final List<ExtendThirdProxyService> extendThirdProxyServices = getExtendThirdProxyServices();
        for (final ExtendThirdProxyService proxyService : extendThirdProxyServices) {
            if (proxyService.getKey().equals(thirdType)) {
                switch (thirdType.hashCode()) {
                    case -2110133105: {
                        if (!thirdType.equals("wpsCenterV6")) {
                            continue;
                        }
                        final SysAttExtendWpsCenterV6ProxyService serviceV6 = (SysAttExtendWpsCenterV6ProxyService)proxyService.getProxyService();
                        if ("true".equals(params.getString("sync"))) {
                            result = serviceV6.operateCleanSync(params);
                            continue;
                        }
                        result = serviceV6.operateCleanTask(params);
                        continue;
                    }
                    case -1713925713: {
                        if (!thirdType.equals("wpsCenter")) {
                            continue;
                        }
                        final SysAttExtendWpsCenterProxyService service = (SysAttExtendWpsCenterProxyService)proxyService.getProxyService();
                        result = service.operateClean(params);
                        continue;
                    }
                    default: {
                        continue;
                    }
                }
            }
        }
        return result;
    }
    
    public static ThirdSfsResponseResult convert(final String thirdType, final JSONObject params) throws Exception {
        ThirdSfsResponseResult result = null;
        final List<ExtendThirdProxyService> extendThirdProxyServices = getExtendThirdProxyServices();
        for (final ExtendThirdProxyService proxyService : extendThirdProxyServices) {
            if (proxyService.getKey().equals(thirdType)) {
                switch (thirdType.hashCode()) {
                    case -2110133105: {
                        if (!thirdType.equals("wpsCenterV6")) {
                            continue;
                        }
                        final SysAttExtendWpsCenterV6ProxyService serviceV6 = (SysAttExtendWpsCenterV6ProxyService)proxyService.getProxyService();
                        if ("true".equals(params.getString("sync"))) {
                            result = serviceV6.convertSync(params);
                            continue;
                        }
                        result = serviceV6.convertAsync(params);
                        continue;
                    }
                    case -1713925713: {
                        if (!thirdType.equals("wpsCenter")) {
                            continue;
                        }
                        final SysAttExtendWpsCenterProxyService service = (SysAttExtendWpsCenterProxyService)proxyService.getProxyService();
                        result = service.convert(params);
                        continue;
                    }
                    case -890917328: {
                        if (!thirdType.equals("suwell")) {
                            continue;
                        }
                        final SysAttExtendSuwellProxyService suwellProxyService = (SysAttExtendSuwellProxyService)proxyService.getProxyService();
                        if ("true".equals(params.getString("sync"))) {
                            result = suwellProxyService.convertSync(params);
                            continue;
                        }
                        result = suwellProxyService.convertAsync(params);
                        continue;
                    }
                    default: {
                        continue;
                    }
                }
            }
        }
        return result;
    }
    
    public static ThirdSfsResponseResult isConverted(final String thirdType, final JSONObject params) throws Exception {
        ThirdSfsResponseResult result = null;
        final List<ExtendThirdProxyService> extendThirdProxyServices = getExtendThirdProxyServices();
        for (final ExtendThirdProxyService proxyService : extendThirdProxyServices) {
            if (proxyService.getKey().equals(thirdType)) {
                switch (thirdType.hashCode()) {
                    case -2110133105: {
                        if (!thirdType.equals("wpsCenterV6")) {
                            continue;
                        }
                        final SysAttExtendWpsCenterV6ProxyService serviceV6 = (SysAttExtendWpsCenterV6ProxyService)proxyService.getProxyService();
                        result = serviceV6.queryTask(params);
                        continue;
                    }
                    case 97624634: {
                        if (!thirdType.equals("foxit")) {
                            continue;
                        }
                        final SysAttExtendFoxitProxyService service = (SysAttExtendFoxitProxyService)proxyService.getProxyService();
                        result = service.isConverted(params);
                        continue;
                    }
                    default: {
                        continue;
                    }
                }
            }
        }
        return result;
    }
    
    public static SysAttStandardThirdProxyService getStandardThirdProxyService(final String thirdType) {
        if (StringUtil.isNull(thirdType)) {
            return null;
        }
        final List<StandardThirdProxyService> standardThirdProxyServices = getStandardThirdProxyServices();
        for (final StandardThirdProxyService proxyService : standardThirdProxyServices) {
            if (proxyService.getKey().equals(thirdType)) {
                return proxyService.getProxyService();
            }
        }
        return null;
    }
    
    private static List<StandardThirdProxyService> getStandardThirdProxyServices() {
        if (SysAttThirdProxyUtil.standardThirdProxyServices.isEmpty()) {
            synchronized (SysAttThirdProxyUtil.standardThirdProxyServices) {
                if (SysAttThirdProxyUtil.standardThirdProxyServices.isEmpty()) {
                    final IExtensionPoint point = Plugin.getExtensionPoint("com.landray.kmss.sys.attachment.third.sfs.service");
                    final IExtension[] extensions = point.getExtensions();
                    IExtension[] array;
                    for (int length = (array = extensions).length, i = 0; i < length; ++i) {
                        final IExtension extension = array[i];
                        if ("proxyStandard".equals(extension.getAttribute("name"))) {
                            final String key = Plugin.getParamValueString(extension, "key");
                            final String name = Plugin.getParamValueString(extension, "name");
                            final String serviceName = Plugin.getParamValueString(extension, "service");
                            final SysAttStandardThirdProxyService proxyService = (SysAttStandardThirdProxyService)SpringBeanUtil.getBean(serviceName);
                            SysAttThirdProxyUtil.standardThirdProxyServices.add(new StandardThirdProxyService(key, name, proxyService));
                        }
                    }
                }
                monitorexit(SysAttThirdProxyUtil.standardThirdProxyServices);
            }
        }
        return SysAttThirdProxyUtil.standardThirdProxyServices;
    }
    
    private static List<ExtendThirdProxyService> getExtendThirdProxyServices() {
        if (SysAttThirdProxyUtil.extendThirdProxyServices.isEmpty()) {
            synchronized (SysAttThirdProxyUtil.extendThirdProxyServices) {
                if (SysAttThirdProxyUtil.extendThirdProxyServices.isEmpty()) {
                    final IExtensionPoint point = Plugin.getExtensionPoint("com.landray.kmss.sys.attachment.third.sfs.service");
                    final IExtension[] extensions = point.getExtensions();
                    IExtension[] array;
                    for (int length = (array = extensions).length, i = 0; i < length; ++i) {
                        final IExtension extension = array[i];
                        if ("proxyExtend".equals(extension.getAttribute("name"))) {
                            final String key = Plugin.getParamValueString(extension, "key");
                            final String name = Plugin.getParamValueString(extension, "name");
                            final String serviceName = Plugin.getParamValueString(extension, "service");
                            final SysAttExtendThirdProxyService proxyService = (SysAttExtendThirdProxyService)SpringBeanUtil.getBean(serviceName);
                            SysAttThirdProxyUtil.extendThirdProxyServices.add(new ExtendThirdProxyService(key, name, proxyService));
                        }
                    }
                }
                monitorexit(SysAttThirdProxyUtil.extendThirdProxyServices);
            }
        }
        return SysAttThirdProxyUtil.extendThirdProxyServices;
    }
    
    static class StandardThirdProxyService
    {
        private String key;
        private String name;
        private SysAttStandardThirdProxyService proxyService;
        
        public StandardThirdProxyService(final String key, final String name, final SysAttStandardThirdProxyService proxyService) {
            this.key = key;
            this.name = name;
            this.proxyService = proxyService;
        }
        
        public String getKey() {
            return this.key;
        }
        
        public String getName() {
            return this.name;
        }
        
        public SysAttStandardThirdProxyService getProxyService() {
            return this.proxyService;
        }
    }
    
    static class ExtendThirdProxyService
    {
        private String key;
        private String name;
        private SysAttExtendThirdProxyService proxyService;
        
        public ExtendThirdProxyService(final String key, final String name, final SysAttExtendThirdProxyService proxyService) {
            this.key = key;
            this.name = name;
            this.proxyService = proxyService;
        }
        
        public String getKey() {
            return this.key;
        }
        
        public String getName() {
            return this.name;
        }
        
        public SysAttExtendThirdProxyService getProxyService() {
            return this.proxyService;
        }
    }
}
